@@ -10,6 +10,8 @@ DCORE_USE_NAMESPACE
 #include <QFontDatabase>
 #include <QImageReader>
 
+#include "base/consts.h"
+
 QHash<QString, QPixmap> Utils::m_imgCacheHash;
 QHash<QString, QString> Utils::m_fontNameCache;
 QString Utils::cpuModeName;
@@ -25,26 +27,31 @@ const int langCount = 5;
 QString languageArr[][langCount] = {
     //dde model
     {"controlcenter", "控制中心", "Control Center", "控制中心", "控制中心"},
-    {"accounts", "帐户设置", "Accounts", "賬號設置", "帳戶設定"},
+    {"", "首页介绍", "Homepage Introduction", "首頁介紹", "首頁介紹"},
+    {"authentication", "生物认证", "Biometric Authentication", "生物認證", "生物認證"},
+    {"passkey", "安全密钥", "Security key", "安全密鑰", "安全金鑰"},
+    {"accounts", "帐户设置", "Accounts", "帳戶設定", "帳戶設定"},
     {"cloudsync", "Union ID", "Union ID", "Union ID", "Union ID"},
-    {"display", "显示设置", "Display", "顯示設置", "螢幕設定"},
-    {"defapp", "默认程序设置", "Default Applications", "默認程序設置", "預設程式"},
-    {"personalization", "个性化设置", "Personalization Settings", "個性化設置", "個性化設定"},
-    {"network", "网络设置", "Network Settings", "網絡設置", "網路設定"},
-    {"notification", "通知设置", "Notification Settings", "通知設置", "通知設定"},
-    {"sound", "声音设置", "Sound Settings", "聲音設置", "聲音設定"},
-    {"bluetooth", "蓝牙设置", "Bluetooth Settings", "藍牙設置", "藍牙設定"},
-    {"datetime", "时间日期", "Date and Time", "日期與時刻", "時間日期"},
+    {"display", "显示设置", "Display", "螢幕設定", "螢幕設定"},
+    {"defapp", "默认程序设置", "Default Applications", "預設程式", "預設程式"},
+    {"personalization", "个性化设置", "Personalization Settings", "個性化設定", "個性化設定"},
+    {"network", "网络设置", "Network Settings", "網路設定", "網路設定"},
+    {"notification", "通知设置", "Notification Settings", "通知設定", "通知設定"},
+    {"sound", "声音设置", "Sound Settings", "聲音設定", "聲音設定"},
+    {"bluetooth", "蓝牙设置", "Bluetooth Settings", "藍牙設定", "藍牙設定"},
+    {"datetime", "时间和格式", "Date and Format", "時間和格式", "時間和格式"},
     {"power", "电源管理", "Power Management", "電源管理", "電源管理"},
-    {"mouse", "鼠标和触控板", "Mouse and Touchpad", "鼠標和觸控板", "滑鼠和觸控板"},
+    {"mouse", "鼠标和触控板", "Mouse and Touchpad", "滑鼠和觸控板", "滑鼠和觸控板"},
     {"tablet", "数位板", "Drawing Tablet", "數位板", "數位板"},
     {"keyboard", "键盘和语言", "Keyboard and Language", "鍵盤和語言", "鍵盤和語言"},
     {"voice", "辅助功能", "Assistive Tools", "輔助功能", "輔助功能"},
-    {"update", "系统更新", "Update Settings", "更新", "檢查更新"},
-    {"systeminfo", "系统信息", "System Info", "系統訊息", "系統資訊"},
+    {"privacy", "隐私和安全", "Privacy and Security", "私隱和安全", "隱私和安全"},
+    {"update", "系统更新", "Update Settings", "檢查更新", "檢查更新"},
+    {"systeminfo", "系统信息", "System Info", "系統資訊", "系統資訊"},
     {"License activator", "授权管理", "Authorization Management", "授權管理", "授權管理"},
-    {"commoninfo", "通用设置", "General Settings", "通用設置", "一般設定"},
-    {"touchscreen", "触控屏设置", "Touch Screen", "觸控屏設置", "觸控屏設定"}
+    {"Backup and Restore", "备份还原", "Backup and Restore", "備份還原", "備份還原"},
+    {"commoninfo", "通用设置", "General Settings", "一般設定", "一般設定"},
+    {"touchscreen", "触控屏设置", "Touch Screen", "觸控屏設定", "觸控屏設定"},
 };
 
 struct ReplyStruct {
@@ -243,7 +250,7 @@ QStringList Utils::getMdsourcePath()
         sourcePath.push_back(pathlist[i] + "/deepin-manual/manual-assets");
     }
     sourcePath.push_back(DMAN_MANUAL_DIR);
-    qDebug() << " all MD source path : " << sourcePath.last();
+    // qDebug() << " all MD source path : " << sourcePath.last();
     return sourcePath;
 }
 
@@ -252,7 +259,7 @@ QStringList Utils::getEnvsourcePath()
     QStringList pathlist = QString(qgetenv("XDG_DATA_DIRS")).split(':');
     if (pathlist.size() == 1 && pathlist[0].isEmpty())
         pathlist[0] = "/usr/share";
-    qDebug() << " all source path : " << pathlist;
+    // qDebug() << " all source path : " << pathlist;
     return pathlist;
 }
 
@@ -279,17 +286,18 @@ QStringList Utils::getSystemManualList()
 {
     QStringList app_list_;
     QStringList strMANUAL_DIR_list = Utils::getMdsourcePath();
+    Dtk::Core::DSysInfo::UosEdition type = Utils::uosEditionType();
     foreach (auto strMANUAL_DIR, strMANUAL_DIR_list) {
         const QStringList applicationList = QDir(QString("%1/application/").arg(strMANUAL_DIR)).entryList(QDir::Dirs|QDir::NoDotAndDotDot);
         const QStringList systemList = QDir(QString("%1/system/").arg(strMANUAL_DIR)).entryList(QDir::Dirs|QDir::NoDotAndDotDot);
         QString oldMdPath = strMANUAL_DIR;
         if (Dtk::Core::DSysInfo::UosServer == Dtk::Core::DSysInfo::uosType()) {
             oldMdPath += "/server";
-        } else if (Dtk::Core::DSysInfo::UosHome == Dtk::Core::DSysInfo::uosEditionType()) {
+        } else if (Dtk::Core::DSysInfo::UosHome == type) {
             oldMdPath += "/personal";
-        } else if (Dtk::Core::DSysInfo::UosEducation == Dtk::Core::DSysInfo::uosEditionType()) {
+        } else if (Dtk::Core::DSysInfo::UosEducation == type) {
             oldMdPath += "/education";
-        } else if (Dtk::Core::DSysInfo::UosCommunity == Dtk::Core::DSysInfo::uosEditionType()) {
+        } else if (Dtk::Core::DSysInfo::UosCommunity == type) {
             oldMdPath += "/community";
         } else {
             oldMdPath += "/professional";
@@ -305,6 +313,16 @@ QStringList Utils::getSystemManualList()
                 app_list_.append("dde");
             }
         }
+        // 非应用文档，直接添加
+        if (systemList.contains(kLearnBasicOperations) || oldAppList.contains(kLearnBasicOperations)) {
+            if (Dtk::Core::DSysInfo::UosCommunity != type && app_list_.indexOf(kLearnBasicOperations) == -1)
+                app_list_.append(kLearnBasicOperations);
+        }
+        if (systemList.contains(kCommonApplicationLibraries) || oldAppList.contains(kCommonApplicationLibraries)) {
+            if (Dtk::Core::DSysInfo::UosCommunity != type && app_list_.indexOf(kCommonApplicationLibraries) == -1 )
+                app_list_.append(kCommonApplicationLibraries);
+        }
+        qDebug() << "exist app list: " << app_list_ << ", count:" << app_list_.size();
     }
     qDebug() << "exist app list: " << app_list_ << ", count:" << app_list_.size();
     return app_list_;
@@ -328,26 +346,26 @@ QStringList Utils::getSystemManualDir()
  */
 QList<AppInfo> Utils::sortAppList(QMultiMap<qlonglong, AppInfo> map)
 {
-    QMapIterator<qlonglong, AppInfo> it(map);
     QList<AppInfo> listEnd;
     QList<AppInfo> listtmp;
     qlonglong longlongtmp = 0;
-    while (it.hasNext()) {
-        it.next();
+    QMultiMap<qlonglong, AppInfo>::const_iterator it = map.constBegin();
+    while (it != map.constEnd()) {
         //只在第一次循环时插入listtemp
-        if (it.value().key == map.first().key) {
+        if (listtmp.isEmpty()) {
             listtmp.append(it.value());
             longlongtmp = it.key();
+            ++it;
             continue;
         }
 
         //如果这本次key与longlongtemp相等说明，当前应用的安装时间与上一次循环中的应用安装时间相同，把appInfo插入listtemp等待排序
-        //如果不相等，listtemp不为null，则对littemp按“应用包名”进行排序；
+        //如果不相等，listtemp不为null，则对littemp按"应用包名"进行排序；
         //并把排序结果添加到listEnd;
         //清空listtmp, 修改longlongtmp记录当前key;
         if (it.key() == longlongtmp) {
             listtmp.append(it.value());
-        } else if (listtmp.size() != 0 && it.key() != longlongtmp) {
+        } else if (!listtmp.isEmpty() && it.key() != longlongtmp) {
             AppInfo m;
             for (int i = 0; i < listtmp.size(); ++i) {
                 for (int j = 0; j < listtmp.size() - 1; ++j) {
@@ -363,6 +381,7 @@ QList<AppInfo> Utils::sortAppList(QMultiMap<qlonglong, AppInfo> map)
             longlongtmp = it.key();
             listtmp.append(it.value());
         }
+        ++it;
     }
     //最后判断listtmp是否为空，处理循环结束时，最后几次longlongtmp都是相等的情况
     if (!listtmp.isEmpty()) {
@@ -392,7 +411,7 @@ QList<AppInfo> Utils::sortAppList(QMultiMap<qlonglong, AppInfo> map)
  */
 bool Utils::hasSelperSupport()
 {
-    Dtk::Core::DSysInfo::UosEdition type = Dtk::Core::DSysInfo::uosEditionType();
+    Dtk::Core::DSysInfo::UosEdition type = uosEditionType();
     //专业版判断是否有服务与支持
     if (Dtk::Core::DSysInfo::UosProfessional == type || Dtk::Core::DSysInfo::UosMilitary == type || Dtk::Core::DSysInfo::UosMilitaryS == type) {
         const QStringList list = getSystemManualList();
@@ -403,6 +422,120 @@ bool Utils::hasSelperSupport()
     return false;
 }
 
+bool checkOsBuildValid(const QString& str)
+{
+    // Format like ABCDE.xyz.abc
+    static QRegularExpression regex("^[1-9A-Z][1-9A-Z][0-9A-Z][1-9A-Z][1-9A-Z](\\.\\w+)*$");
+
+    return regex.match(str).hasMatch();
+}
+
+Dtk::Core::DSysInfo::UosEdition Utils::uosEditionType()
+{
+    // Add static cache, query only once    
+    static Dtk::Core::DSysInfo::UosEdition cachedEdition = Dtk::Core::DSysInfo::UosEdition::UosEditionUnknown;
+    static bool hasQueried = false;
+    
+    // If already queried, return cached result
+    if (hasQueried) {
+        return cachedEdition;
+    }
+    
+    QDBusInterface interface("org.deepin.dde.SystemInfo1",
+                            "/org/deepin/dde/SystemInfo1",
+                            "org.deepin.dde.SystemInfo1",
+                            QDBusConnection::sessionBus());
+
+    if(!interface.isValid()) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    QVariant osBuild = interface.property("OsBuild");
+    if(!osBuild.isValid()) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    QString buildType = osBuild.toString();
+    if(buildType.isEmpty()) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    QStringList parts = buildType.split(".");
+    if(parts.size() != 3) {
+        hasQueried = true;
+        return cachedEdition;
+    }
+
+    // Save result to cache
+    cachedEdition = parseOsBuildType(parts[0]);
+    hasQueried = true;
+    return cachedEdition;
+}
+
+Dtk::Core::DSysInfo::UosEdition Utils::parseOsBuildType(const QString & osBuild)
+{
+    if (!checkOsBuildValid(osBuild))
+        return Dtk::Core::DSysInfo::UosEditionUnknown;
+
+    int uosType = osBuild[1].digitValue();
+    int uosEditType = osBuild[3].digitValue();
+    // copy from dtk-core/src/dsysinfo.cpp
+    if(uosType == 1) {
+        switch (uosEditType) {
+        case 1:
+            return Dtk::Core::DSysInfo::UosEdition::UosProfessional;
+        case 2:
+        case 7:
+            //The new version of the family version (7) and the old version of the personal version (2) The same as the home does not modify the old logic (7) to ensure the adaptation of the old version
+            return Dtk::Core::DSysInfo::UosEdition::UosHome;
+        case 3:
+            return Dtk::Core::DSysInfo::UosEdition::UosCommunity;
+        case 4:
+            return Dtk::Core::DSysInfo::UosEdition::UosMilitary;
+        case 5:
+            return Dtk::Core::DSysInfo::UosEdition::UosDeviceEdition;
+        case 6:
+            return Dtk::Core::DSysInfo::UosEdition::UosEducation;
+        default:
+            break;
+        }
+
+    }else if(uosType == 2) {
+        switch (uosEditType) {
+        case 1:
+            return Dtk::Core::DSysInfo::UosEdition::UosEnterprise;
+        case 2:
+            return Dtk::Core::DSysInfo::UosEdition::UosEnterpriseC;
+        case 3:
+            return Dtk::Core::DSysInfo::UosEdition::UosEuler;
+        case 4:
+            return Dtk::Core::DSysInfo::UosEdition::UosMilitaryS;
+        case 5:
+            return Dtk::Core::DSysInfo::UosEdition::UosDeviceEdition;
+        default:
+            break;
+        }
+    }
+    else if (uosType == 3){
+        return Dtk::Core::DSysInfo::UosEnterprise;
+    }
+
+    return Dtk::Core::DSysInfo::UosEditionUnknown;
+}
+
+bool Utils::hasAppStore()
+{
+    const QStringList list = getSystemManualList();
+    if (list.contains("deepin-app-store")) {
+        return true;
+    } else {
+        return false;
+    }
+}
+
 //p表示桌面专业版，h表示个人版，d表示社区版
 //s表示默认服务器版，e表示服务器企业版，eu表示服务器欧拉版，i表示服务器行业版，klu表示KelvinU项目版本，pgv表示PanguV项目版本。
 QStringList Utils::systemToOmit(Dtk::Core::DSysInfo::UosEdition type)
@@ -471,7 +604,7 @@ QString Utils::regexp_label(const QString &strtext, const QString &strpatter)
     if (match.isValid() && match.hasMatch()) {
         for (int i = 0; i <= match.lastCapturedIndex(); i++) {
             result = match.captured(i);
-            qDebug() << __FUNCTION__ << "-------****" << result;
+            // qDebug() << __FUNCTION__ << "-------****" << result;
             break;
         }
     }
